# GL2100
# Script for G/L Transactions. 
# Assumes you have GL Transaction detail optional fields detail Optional Fields SUBSTENTITY
# Adds the optional field into the G/L Transaction detail entry grid. 
# You can drag & drop them to the left hand side of the grid if required.
# -------------------------------------------------
# Copyright 2018 Orchid Systems 
# The code is supplied on an as is basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
###################################################################################################################################################


from accpac import *

glamfto = None

def main(args):
	MyUI()

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.createScreen()

	def createScreen(self):
		grid = self.getHostControl("vlGLJED")
		self.grid = grid

		col = UIGridColumn()
		col.caption = "Entity"
		col.hasFinder = True
		col.isEditable = True
		grid.addColumn(col, "SRCELDGR") # Hijack the field.


		grid.setOnFinder(self.onGridFinder)
		grid.setOnBeginEdit(self.onGridBeginEdit)
		grid.setOnAfterEdit(self.onGridAfterEdit)
		grid.setOnGetText(self.onGridGetText)

		self.dsGLJED = self.openDataSource("dsGLJED")
		self.ds = self.openDataSource("dsGLJEDO")
		grid.refreshData()
		self.show()

	def onGridBeginEdit(self, e):
		if e.caption == "Entity":
			e.datatype = "TEXT"
			e.width = 10
			e.mask = "%-10C"
			self.onGridGetText(e)


	def onGridAfterEdit(self, e):
		if e.caption == "Entity":
			self.setOptionalField("SUBSTENTITY", e.value)


	def setOptionalField(self, optfield, value):
		glacct = self.dsGLJED.get("ACCTID").strip()
		if glacct != "":
			if self.isOptionalFieldDefined(glacct, optfield) == True:
				self.ds.put("OPTFIELD", optfield)
				if self.ds.read() == 0:
					self.ds.put("VALUE", value)
					self.ds.update()
				else:
					self.ds.recordGenerate()
					self.ds.put("OPTFIELD", optfield)
					self.ds.put("VALUE", value)
					self.ds.insert()

	def isOptionalFieldDefined(self, glacct, optfield):
		global glamfto
		
		if glamfto == None:
			glamfto = openView("GL0401")
		
		glamfto.put("ACCTID", glacct)
		glamfto.put("OPTFIELD", optfield)
		if glamfto.read() == 0:
			return True
		else:
			return False
				
	def onGridGetText(self, e):
	
		if e.caption == "Entity":
			e.value = ""	# init to blank.
		
		glacct = self.dsGLJED.get("ACCTID").strip()
		if glacct != "":
			if e.caption == "Entity":
				if self.isOptionalFieldDefined(glacct, "SUBSTENTITY") == True:
					self.ds.put("OPTFIELD", "SUBSTENTITY")
					if self.ds.read() == 0:
						e.value = self.ds.get("VALUE")
					else:
						e.value = ""


	def onGridFinder(self, fieldName, caption):
		glacct = self.dsGLJED.get("ACCTID").strip()
		if caption == "Entity":
			if glacct != "":
				if self.isOptionalFieldDefined(glacct, "SUBSTENTITY") == True:
					finder = Finder()
					finder.viewID = "CS0012"
					finder.displayFields = "2,4"
					finder.returnFields = "2"
					finder.filter = "OPTFIELD=\"SUBSTENTITY\""
					finder.onOK = self.finder_ok
					finder.onCancel = self.finder_cancel
					finder.show(self)
				else:
					self.grid.preventFinder()
			else:
				self.grid.preventFinder()
				

	def finder_ok(self, e):
		self.grid.endEdit(e)

	def finder_cancel(self):
		self.grid.preventFinder()
